@@ -3,7 +3,7 @@ def print_lol(the_list, indent=False, level=0):
 	"""This function takes a positional argument called "the_list", which is any Python list (of, possibly, nested lists). Each item in the provided list is (recursively) printed to the screen on its own line."""
 	for each_item in the_list: 
 		if isinstance(each_item, list):
-			print_lol(each_item, level+1)
+			print_lol(each_item, indent, level+1)
 		else:
 			if indent:
 				for num in range(level):
